@@ -22,11 +22,11 @@ VSGDR::StaticData - Static data script support package for SSDT post-deployment
 
 =head1 VERSION
 
-Version 0.44
+Version 0.45
 
 =cut
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 
 
 sub databaseName {
@@ -121,7 +121,7 @@ sub generateScript {
     my $database                        = databaseName($dbh);
 
     no warnings;
-    my $userName                        = $OSNAME eq 'MSWin32' ? Win32::LoginName : ${[getpwuid( $< )]}->[6]; $userName =~ s/,.*//;
+    my $userName                        = $OSNAME eq 'MSWin32' ? eval('Win32::LoginName') : ${[getpwuid( $< )]}->[6]; $userName =~ s/,.*//;
     use warnings;                      
 
     my $date                            = strftime "%d/%m/%Y", localtime;
